summaryrefslogtreecommitdiffstats
path: root/src/Reader.php
diff options
context:
space:
mode:
authorignace nyamagana butera <nyamsprod@gmail.com>2014-02-28 15:00:47 +0100
committerignace nyamagana butera <nyamsprod@gmail.com>2014-02-28 15:00:47 +0100
commitf8953568fa1b6910f0cb7e0ec4b861d47db34b17 (patch)
treef76fea2674a633f8cfb15174371caf3bbe5702c1 /src/Reader.php
parent4f1ed587c59c1524599457f8fcc562dcb5b845ed (diff)
parentef58410e9c67a734eb6bdf3a9264b7df6082f501 (diff)
downloadcsv-5.0.0.zip
csv-5.0.0.tar.gz
csv-5.0.0.tar.bz2
Merge pull request #17 from thephpleague/update-namespace5.0.0
Update namespace
Diffstat (limited to 'src/Reader.php')
-rw-r--r--src/Reader.php18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/Reader.php b/src/Reader.php
index a8d6432..3b21e34 100644
--- a/src/Reader.php
+++ b/src/Reader.php
@@ -1,13 +1,13 @@
<?php
/**
* Bakame.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>
* @copyright 2014 Ignace Nyamagana Butera
-* @link https://github.com/nyamsprod/Bakame.csv
+* @link https://github.com/nyamsprod/League.csv
* @license http://opensource.org/licenses/MIT
-* @version 4.2.1
-* @package Bakame.csv
+* @version 5.0.0
+* @package League.csv
*
* MIT LICENSE
*
@@ -30,19 +30,19 @@
* OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
* WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/
-namespace Bakame\Csv;
+namespace League\Csv;
use SplFileObject;
use SplTempFileObject;
use InvalidArgumentException;
use CallbackFilterIterator;
-use Bakame\Csv\Iterator\MapIterator;
-use Bakame\Csv\Iterator\IteratorQuery;
+use League\Csv\Iterator\MapIterator;
+use League\Csv\Iterator\IteratorQuery;
/**
* A class to manage extracting and filtering a CSV
*
- * @package Bakame.csv
+ * @package League.csv
* @since 3.0.0
*
*/
@@ -192,7 +192,7 @@ class Reader extends AbstractCsv
*
* @param string $open_mode the file open mode flag
*
- * @return \Bakame\Csv\Writer
+ * @return \League\Csv\Writer
*/
public function getWriter($open_mode = 'w')
{
@@ -1,13 +1,13 @@
<?php
/**
-* Bakame.csv - A lightweight CSV Coder/Decoder library
+* League.csv - A lightweight CSV Coder/Decoder library
*
* @author Ignace Nyamagana Butera <nyamsprod@gmail.com>